# -*- coding: utf-8 -*-
from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)

# copie automatique de chaque resultat dans le presse-papier
copie_automatique = False
# 0 -> Tableau de variation ; 1 -> Tableau de signe ; 2 -> Tableau de valeurs
mode = 0
utiliser_cellspace = False
derivee = True
limites = True
formatage_antecedents = r"\nombre{VAL}"
formatage_images = r"\nombre{VAL}"
# Nombre de décimales, ou None pour les valeurs exactes
decimales_tabvar_tabsign = -1
decimales_tabval = 2
